Please see [https://docs.mlcommons.org/cm4mlops/scripts/Cloud-automation/run-terraform](https://docs.mlcommons.org/cm4mlops/scripts/Cloud-automation/run-terraform) for the documentation of this CM script.
